# PiicoDev Sketcher Project
# Use the knobs to draw a picture. One knob controls the x-position of the stylus, and the other controls the y-position
# Shake to clear!

# Import PiicoDev Libraries
from PiicoDev_Potentiometer import PiicoDev_Potentiometer
from PiicoDev_SSD1306 import *
from PiicoDev_LIS3DH import PiicoDev_LIS3DH
from PiicoDev_Unified import sleep_ms
from random import random

# Initialise Hardware
pot_x = PiicoDev_Potentiometer(id=[0,0,0,0], minimum=0, maximum=127)
pot_y = PiicoDev_Potentiometer(id=[1,0,0,0], minimum=127, maximum=0)
display = create_PiicoDev_SSD1306()
motion = PiicoDev_LIS3DH()

# Functions
def animation_reset():
    """ Clear a percentage of all pixels, decaying the image """
    for i in range(5):
        for x in range(WIDTH):
            for y in range(HEIGHT):
                if random() < 0.2:
                    display.pixel(x,y,0)
        display.show()

# Show a nice splash-screen
display.load_pbm('splash.pbm', 1)
display.show()
sleep_ms(2000)
display.fill(0)

x_prev = int(pot_x.value)
y_prev = int(pot_y.value)

while True:
    # Read pots, use as (x,y) pixel coordinate
    x = int(round(pot_x.value))
    y = int(round(pot_y.value))
    y = min(y,63) # Make sure y does not go beyond edge of screen
    
    display.line(x_prev, y_prev, x, y, 1) # Draw a line (x,y) on the previous frame, and (x,y) on this frame
    display.show()
    x_prev = x
    y_prev = y
    
    # Check for shaking, clear the display
    if motion.shake(threshold = 20, avg_count=10, total_delay=25): # shake() is blocking for total_delay=25ms, so we don't need call to sleep_ms() in our loop
        animation_reset()